@@ -67,7 +67,7 @@ from docopt import DocoptExit
 import requests
 from termcolor import colored
 
-__version__ = '0.14.0'
+__version__ = '0.15.0'
 
 
 locale.setlocale(locale.LC_ALL, '')
@@ -446,7 +446,7 @@ class DeisClient(object):
         finally:
             progress.cancel()
             progress.join()
-        if response.status_code == requests.codes.created:  # @UndefinedVariable
+        if response.status_code == requests.codes.created:
             data = response.json()
             app_id = data['id']
             self._logger.info("done, created {}".format(app_id))
@@ -510,8 +510,8 @@ class DeisClient(object):
         finally:
             progress.cancel()
             progress.join()
-        if response.status_code in (requests.codes.no_content,  # @UndefinedVariable
-                                    requests.codes.not_found):  # @UndefinedVariable
+        if response.status_code in (requests.codes.no_content,
+                                    requests.codes.not_found):
             self._logger.info('done in {}s'.format(int(time.time() - before)))
             try:
                 # If the requested app is a heroku app, delete the git remote
@@ -532,7 +532,7 @@ class DeisClient(object):
         Usage: deis apps:list
         """
         response = self._dispatch('get', '/v1/apps')
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             data = response.json()
             self._logger.info('=== Apps')
             for item in data['results']:
@@ -554,7 +554,7 @@ class DeisClient(object):
         if not app:
             app = self._session.app
         response = self._dispatch('get', "/v1/apps/{}".format(app))
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             self._logger.info("=== {} Application".format(app))
             self._logger.info(json.dumps(response.json(), indent=2) + '\n')
             self.ps_list(args)
@@ -578,7 +578,7 @@ class DeisClient(object):
             app = self._session.app
         # TODO: replace with a single API call to apps endpoint
         response = self._dispatch('get', "/v1/apps/{}".format(app))
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             url = response.json()['url']
             # use the OS's default handler to open this URL
             webbrowser.open('http://{}/'.format(url))
@@ -601,7 +601,7 @@ class DeisClient(object):
             app = self._session.app
         response = self._dispatch('get',
                                   "/v1/apps/{}/logs".format(app))
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             # strip the last newline character
             for line in response.json().split('\n')[:-1]:
                 # get the tag from the log
@@ -646,7 +646,7 @@ class DeisClient(object):
         response = self._dispatch('post',
                                   "/v1/apps/{}/run".format(app),
                                   json.dumps(body))
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             rc, output = json.loads(response.content)
             sys.stdout.write(output)
             sys.stdout.flush()
@@ -659,10 +659,11 @@ class DeisClient(object):
         Valid commands for auth:
 
         auth:register          register a new user
-        auth:cancel            remove the current account
         auth:login             authenticate against a controller
         auth:logout            clear the current user session
-        auth:whoami            display the authenticated user
+        auth:passwd            change the password for the current user
+        auth:whoami            display the current user
+        auth:cancel            remove the current user account
 
         Use `deis help [command]` to learn more.
         """
@@ -705,7 +706,7 @@ class DeisClient(object):
         url = urlparse.urljoin(controller, '/v1/auth/register')
         payload = {'username': username, 'password': password, 'email': email}
         response = self._session.post(url, data=payload, allow_redirects=False)
-        if response.status_code == requests.codes.created:  # @UndefinedVariable
+        if response.status_code == requests.codes.created:
             self._settings['controller'] = controller
             self._settings.save()
             self._logger.info("Registered {}".format(username))
@@ -771,7 +772,7 @@ class DeisClient(object):
         payload = {'username': username, 'password': password}
         # post credentials to the login URL
         response = self._session.post(url, data=payload, allow_redirects=False)
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             # retrieve and save the API token for future requests
             self._settings['controller'] = controller
             self._settings['username'] = username
@@ -794,6 +795,40 @@ class DeisClient(object):
         self._settings.save()
         self._logger.info('Logged out')
 
+    def auth_passwd(self, args):
+        """
+        Changes the password for the current user.
+
+        Usage: deis auth:passwd [options]
+
+        Options:
+          --password=<password>
+            provide the current password for the account.
+          --new-password=<new-password>
+            provide a new password for the account.
+        """
+        if not self._settings.get('token'):
+            raise EnvironmentError(
+                'Could not find token. Use `deis login` or `deis register` to get started.')
+        password = args.get('--password')
+        if not password:
+            password = getpass('current password: ')
+        new_password = args.get('--new-password')
+        if not new_password:
+            new_password = getpass('new password: ')
+            confirm = getpass('new password (confirm): ')
+            if new_password != confirm:
+                self._logger.error('Password mismatch, not changing.')
+                sys.exit(1)
+        payload = {'password': password, 'new_password': new_password}
+        response = self._dispatch('post', "/v1/auth/passwd", json.dumps(payload))
+        if response.status_code == requests.codes.ok:
+            self._logger.info('Password change succeeded.')
+        else:
+            self._logger.info("Password change failed: {}".format(response.text))
+            sys.exit(1)
+        return True
+
     def auth_whoami(self, args):
         """
         Displays the currently logged in user.
@@ -849,7 +884,7 @@ class DeisClient(object):
         finally:
             progress.cancel()
             progress.join()
-        if response.status_code == requests.codes.created:  # @UndefinedVariable
+        if response.status_code == requests.codes.created:
             version = response.headers['x-deis-release']
             self._logger.info("done, v{}".format(version))
         else:
@@ -869,7 +904,7 @@ class DeisClient(object):
         if not app:
             app = self._session.app
         response = self._dispatch('get', "/v1/apps/{}/builds".format(app))
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             self._logger.info("=== {} Builds".format(app))
             data = response.json()
             for item in data['results']:
@@ -911,7 +946,7 @@ class DeisClient(object):
 
         oneline = args.get('--oneline')
         response = self._dispatch('get', "/v1/apps/{}/config".format(app))
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             config = response.json()
             values = config['values']
             self._logger.info("=== {} Config".format(app))
@@ -964,7 +999,7 @@ class DeisClient(object):
         finally:
             progress.cancel()
             progress.join()
-        if response.status_code == requests.codes.created:  # @UndefinedVariable
+        if response.status_code == requests.codes.created:
             version = response.headers['x-deis-release']
             self._logger.info("done, v{}\n".format(version))
             config = response.json()
@@ -1010,7 +1045,7 @@ class DeisClient(object):
         finally:
             progress.cancel()
             progress.join()
-        if response.status_code == requests.codes.created:  # @UndefinedVariable
+        if response.status_code == requests.codes.created:
             version = response.headers['x-deis-release']
             self._logger.info("done, v{}\n".format(version))
             config = response.json()
@@ -1057,7 +1092,7 @@ class DeisClient(object):
             except IOError:
                 pass
         response = self._dispatch('get', "/v1/apps/{}/config".format(app))
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             config = response.json()['values']
             for k, v in config.items():
                 if interactive and raw_input("overwrite {} with {}? (y/N) ".format(k, v)) == 'y':
@@ -1119,7 +1154,7 @@ class DeisClient(object):
         finally:
             progress.cancel()
             progress.join()
-        if response.status_code == requests.codes.created:  # @UndefinedVariable
+        if response.status_code == requests.codes.created:
             self._logger.info("done")
         else:
             raise ResponseError(response)
@@ -1152,7 +1187,7 @@ class DeisClient(object):
         finally:
             progress.cancel()
             progress.join()
-        if response.status_code == requests.codes.no_content:  # @UndefinedVariable
+        if response.status_code == requests.codes.no_content:
             self._logger.info("done")
         else:
             raise ResponseError(response)
@@ -1172,7 +1207,7 @@ class DeisClient(object):
             app = self._session.app
         response = self._dispatch(
             'get', "/v1/apps/{app}/domains".format(app=app))
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             domains = response.json()['results']
             self._logger.info("=== {} Domains".format(app))
             if len(domains) == 0:
@@ -1211,7 +1246,7 @@ class DeisClient(object):
         if not app:
             app = self._session.app
         response = self._dispatch('get', "/v1/apps/{}/config".format(app))
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             self._print_limits(app, response.json())
         else:
             raise ResponseError(response)
@@ -1267,7 +1302,7 @@ class DeisClient(object):
         finally:
             progress.cancel()
             progress.join()
-        if response.status_code == requests.codes.created:  # @UndefinedVariable
+        if response.status_code == requests.codes.created:
             version = response.headers['x-deis-release']
             self._logger.info("done, v{}\n".format(version))
 
@@ -1313,7 +1348,7 @@ class DeisClient(object):
         finally:
             progress.cancel()
             progress.join()
-        if response.status_code == requests.codes.created:  # @UndefinedVariable
+        if response.status_code == requests.codes.created:
             version = response.headers['x-deis-release']
             self._logger.info("done, v{}\n".format(version))
             self._print_limits(app, response.json())
@@ -1368,7 +1403,7 @@ class DeisClient(object):
                 app = self._session.app
         response = self._dispatch('get',
                                   "/v1/apps/{}/containers".format(app))
-        if response.status_code != requests.codes.ok:  # @UndefinedVariable
+        if response.status_code != requests.codes.ok:
             raise ResponseError(response)
         processes = response.json()
         self._logger.info("=== {} Processes\n".format(app))
@@ -1417,7 +1452,7 @@ class DeisClient(object):
         finally:
             progress.cancel()
             progress.join()
-        if response.status_code == requests.codes.no_content:  # @UndefinedVariable
+        if response.status_code == requests.codes.no_content:
             self._logger.info('done in {}s'.format(int(time.time() - before)))
             self.ps_list({}, app)
         else:
@@ -1451,7 +1486,7 @@ class DeisClient(object):
         if not app:
             app = self._session.app
         response = self._dispatch('get', "/v1/apps/{}/config".format(app))
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             self._print_tags(app, response.json())
         else:
             raise ResponseError(response)
@@ -1487,7 +1522,7 @@ class DeisClient(object):
         finally:
             progress.cancel()
             progress.join()
-        if response.status_code == requests.codes.created:  # @UndefinedVariable
+        if response.status_code == requests.codes.created:
             version = response.headers['x-deis-release']
             self._logger.info("done, v{}\n".format(version))
 
@@ -1525,7 +1560,7 @@ class DeisClient(object):
         finally:
             progress.cancel()
             progress.join()
-        if response.status_code == requests.codes.created:  # @UndefinedVariable
+        if response.status_code == requests.codes.created:
             version = response.headers['x-deis-release']
             self._logger.info("done, v{}\n".format(version))
             self._print_tags(app, response.json())
@@ -1585,7 +1620,7 @@ class DeisClient(object):
         sys.stdout.write("Uploading {} to Deis...".format(selected_key.id))
         sys.stdout.flush()
         response = self._dispatch('post', '/v1/keys', json.dumps(body))
-        if response.status_code == requests.codes.created:  # @UndefinedVariable
+        if response.status_code == requests.codes.created:
             self._logger.info('done')
         else:
             raise ResponseError(response)
@@ -1639,7 +1674,7 @@ class DeisClient(object):
         Usage: deis keys:list
         """
         response = self._dispatch('get', '/v1/keys')
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             data = response.json()
             if data['count'] == 0:
                 self._logger.info('No keys found')
@@ -1666,7 +1701,7 @@ class DeisClient(object):
         sys.stdout.write("Removing {} SSH Key... ".format(key))
         sys.stdout.flush()
         response = self._dispatch('delete', "/v1/keys/{}".format(key))
-        if response.status_code == requests.codes.no_content:  # @UndefinedVariable
+        if response.status_code == requests.codes.no_content:
             self._logger.info('done')
         else:
             raise ResponseError(response)
@@ -1822,7 +1857,7 @@ class DeisClient(object):
             app = self._session.app
         response = self._dispatch(
             'get', "/v1/apps/{app}/releases/{version}".format(**locals()))
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             self._logger.info(json.dumps(response.json(), indent=2))
         else:
             raise ResponseError(response)
@@ -1841,7 +1876,7 @@ class DeisClient(object):
         if not app:
             app = self._session.app
         response = self._dispatch('get', "/v1/apps/{app}/releases".format(**locals()))
-        if response.status_code == requests.codes.ok:  # @UndefinedVariable
+        if response.status_code == requests.codes.ok:
             self._logger.info("=== {} Releases".format(app))
             data = response.json()
             for item in data['results']:
@@ -1887,7 +1922,7 @@ class DeisClient(object):
         finally:
             progress.cancel()
             progress.join()
-        if response.status_code == requests.codes.created:  # @UndefinedVariable
+        if response.status_code == requests.codes.created:
             new_version = response.json()['version']
             self._logger.info("done, v{}".format(new_version))
         else:
@@ -1913,6 +1948,7 @@ SHORTCUTS = OrderedDict([
     ('logout', 'auth:logout'),
     ('logs', 'apps:logs'),
     ('open', 'apps:open'),
+    ('passwd', 'auth:passwd'),
     ('pull', 'builds:create'),
     ('register', 'auth:register'),
     ('rollback', 'releases:rollback'),
